import axios from 'axios';

// Determine environment and set baseURL accordingly
const environment = import.meta.env.VITE_ENVIRONMENT;
const baseURL = environment === 'production'
  ? import.meta.env.VITE_API_URL
  : 'http://localhost:5000'; // Default for development

console.log(`Axios baseURL set to: ${baseURL}`); // Log the base URL for debugging

const axiosInstance = axios.create({
  baseURL,
  headers: {
    'Content-Type': 'application/json',
  },
});

// Request interceptor to add JWT token
axiosInstance.interceptors.request.use((config) => {
  const token = localStorage.getItem('token');
  if (token) {
    config.headers['Authorization'] = `Bearer ${token}`;
  }
  return config;
}, error => {
  // Handle request error
  console.error('Request error:', error);
  return Promise.reject(error);
});

// Response interceptor to handle responses globally
axiosInstance.interceptors.response.use(
  response => response,
  error => {
    if (error.response) {
      // Server responded with a status other than 2xx
      console.error('Error response:', error.response.data);
    } else if (error.request) {
      // No response received from the server
      console.error('Error request:', error.request);
    } else {
      // Something else caused the error
      console.error('Error message:', error.message);
    }
    return Promise.reject(error);
  }
);

export default axiosInstance;
