import axiosMock from 'axios';
import axiosInstance from './api/axiosConfig';
import {
  getUsers,
  getUserById,
  createUser,
  updateUser,
  deleteUser,
} from './api/userService';
import MockAdapter from 'axios-mock-adapter';


const mock = new MockAdapter(axiosInstance);

describe('userService', () => {
  afterEach(() => {
    
    mock.reset();
  });

  it('should fetch all users', async () => {
    const users = [{ id: 1, name: 'John Doe' }, { id: 2, name: 'Jane Doe' }];
    mock.onGet('http://localhost:5000/user').reply(200, users);

    const result = await getUsers();
    expect(result).toEqual(users);
  });

  it('should fetch a user by ID', async () => {
    const user = { id: 1, name: 'John Doe' };
    mock.onGet('http://localhost:5000/user/1').reply(200, user);

    const result = await getUserById(1);
    expect(result).toEqual(user);
  });

  it('should create a new user', async () => {
    const newUser = { name: 'John Doe' };
    const createdUser = { id: 1, ...newUser };
    mock.onPost('http://localhost:5000/user').reply(201, createdUser);

    const result = await createUser(newUser);
    expect(result).toEqual(createdUser);
  });

  it('should update a user by ID', async () => {
    const updatedData = { name: 'John Smith' };
    const updatedUser = { id: 1, ...updatedData };
    mock.onPatch('http://localhost:5000/user/1').reply(200, updatedUser);

    const result = await updateUser(1, updatedData);
    expect(result).toEqual(updatedUser);
  });

  it('should delete a user by ID', async () => {
    mock.onDelete('http://localhost:5000/user/1').reply(200);

    const result = await deleteUser(1);
    expect(result).toBeUndefined(); 
  });

  it('should handle errors correctly', async () => {
    mock.onGet('http://localhost:5000/user').reply(500);

    try {
      await getUsers();
    } catch (error) {
      expect(error).toBeTruthy();
    }
  });
});
