import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import axiosInstance from '../../api/axiosConfig'; 
import BrookslogoIcon from '../../assets/thob-data/BrookslogoIcon.svg';

const LoginPage = () => {
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');
  const navigate = useNavigate();

  const handleLogin = async (e) => {
    e.preventDefault();
    setError('');

    try {
      const response = await axiosInstance.get('http://localhost:5000/authlogin');
      const user = response.data.find(user => user.email === email && user.password === password);
      
      if (user) {
        localStorage.setItem("loggedInUser", JSON.stringify(user));
        if (user.role === 'admin') {
          navigate('/admin');
        } else if (user.role === 'employee') {
          navigate('/employee');
        } else {
          setError('Invalid role.');
        }
      } else {
        setError('Invalid credentials');
      }
    } catch (err) {
      if (err.response) {
        setError(`Login failed: ${err.response.data.message}`);
      } else if (err.request) {
        setError('Login failed. No response from server.');
      } else {
        setError('Login failed. Please try again.');
      }
    }
  };

  return (
    <div className="flex flex-col min-h-screen bg-secondary p-4 relative">
      <img src={BrookslogoIcon} alt="Logo" className="absolute top-6 left-6 w-24" />
      <div className="flex flex-col items-center justify-center flex-1 px-4 py-6">
        <h1 className="text-primary-text text-2xl font-bold mb-4">welcome back</h1>
        <p className="text-secondary-text text-center mb-6">be among the first to experience 3D magic! Register for private alpha.</p>
        {error && <p className="text-red-500 text-center mb-4">{error}</p>}
        <div className="flex flex-col space-y-4 w-full max-w-sm">
          <input
            type="email"
            id="email"
            name="email"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
            placeholder="john123@domain.com"
            required
            className="w-full p-3 border border-gray-300 rounded-md text-gray-700 focus:border-primary focus:outline-none"
          />
          <input
            type="password"
            id="password"
            name="password"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
            placeholder="Enter your password"
            required
            className="w-full p-3 border border-gray-300 rounded-md text-gray-700 focus:border-primary focus:outline-none"
          />
          <div className="flex justify-end">
            <a href="/reset-password" className="text-primary-text">forgot password?</a>
          </div>
          <button
            onClick={handleLogin}
            className="w-full py-3 bg-primary text-button-text rounded-md text-lg font-semibold hover:bg-primary-dark"
          >
            login
          </button>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
