import React, { useCallback } from "react";
import { useNavigate, useLocation } from "react-router-dom";
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';
// import ActionButtons from "../components/ActionButtons";
// import Profile from "../components/Profile";

const EmployeeProfile = () => {
  const navigate = useNavigate();
  const location = useLocation();
  const { employee } = location.state || {};

  const onButtonLabelsContainerClick = useCallback(() => {
    navigate("/adminemployee-account-delete");
  }, [navigate]);

  const onHomeIconClick = useCallback(() => {
    navigate("/adminhome");
  }, [navigate]);

  const onHeadingContainerClick = useCallback(() => {
    navigate("/adminemployee-list");
  }, [navigate]);

  if (!employee) {
    return <div>Employee data not found</div>;
  }

  return (
    <div className="w-full relative bg-brooks-color-system-secondary-brand overflow-hidden flex flex-row items-start justify-start leading-[normal] tracking-[normal]">
      <div className="overflow-hidden flex flex-col items-start justify-start pt-4 px-5 pb-[42px] gap-[136px] z-[1] mq450:pb-5 mq450:box-border mq825:pt-5 mq825:pb-[27px] mq825:box-border">
        <div className="flex flex-row items-start justify-start pt-0 px-0 pb-2.5">
          <img
            className="h-10 w-10 relative"
            loading="lazy"
            alt=""
            src="/brooks-logo3.svg"
          />
        </div>
        <div className="flex flex-row items-start justify-start py-0 pr-2 pl-[7px]">
          <div className="flex flex-col items-start justify-start gap-[60px]">
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0 cursor-pointer"
              loading="lazy"
              alt=""
              src="/home-icon3.svg"
              onClick={onHomeIconClick}
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/customer-list-icon3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/orders-iocn3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/category-icon3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/catalog-icon3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/employee-icon3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/measurments-iocn3.svg"
            />
            <img
              className="w-[25px] h-[25px] relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/account-icon3.svg"
            />
          </div>
        </div>
        <div className="w-10 flex flex-row items-start justify-start py-0 pr-2 pl-[7px] box-border">
          <div className="flex flex-col items-start justify-start">
            <img
              className="w-6 h-6 relative overflow-hidden shrink-0"
              loading="lazy"
              alt=""
              src="/materialsymbolslogout3.svg"
            />
          </div>
        </div>
      </div>
      <main className="flex-1 flex flex-col items-start justify-start pt-14 px-0 pb-0 box-border max-w-[calc(100%_-_80px)] mq450:pt-[23px] mq450:box-border mq825:pt-9 mq825:box-border">
        <section className="self-stretch flex flex-col items-start justify-start gap-[35.3px] max-w-full text-center text-5xl text-brooks-color-system-text-colors-secondary-text font-button mq675:gap-[18px]">
          <header className="self-stretch flex flex-col items-start justify-start gap-[26px] max-w-full text-center text-29xl text-brooks-color-system-text-colors-primary-text font-button">
            <div className="flex flex-row items-start justify-start py-0 pr-5 pl-0 box-border">
              <div className="flex flex-col items-start justify-start gap-7">
                <div
                  className="relative tracking-[0.03em] leading-[normal] font-semibold flex items-center w-[250px] h-10 shrink-0 cursor-pointer"
                  onClick={onHeadingContainerClick}
                >
                  <span className="text-xs tracking-[0.03em] leading-[normal] uppercase font-semibold text-brooks-color-system-text-colors-primary-text inline-block w-[170px] h-6 shrink-0 text-left z-[0]">
                    Employee List
                  </span>
                  <img
                    className="w-[19px] h-[19px] relative z-[1] ml-[9px]"
                    loading="lazy"
                    alt=""
                    src="/icon5.svg"
                  />
                </div>
                <div className="relative leading-[normal] font-semibold inline-block w-[270px] h-[30px] shrink-0">
                  Employee Profile
                </div>
              </div>
            </div>
          </header>
          <Profile
            employeeName={`${employee.firstname} ${employee.lastname}`}
            employeeID={employee.id}
          />
        </section>
        <section className="self-stretch flex flex-col items-start justify-start gap-[150px] max-w-full mq675:gap-[85px]">
          <ActionButtons employeeId={employee.id} />
          <footer className="self-stretch flex flex-col items-start justify-start pt-0 px-5 pb-[42px] gap-[66px] max-w-full text-left text-8xl text-brooks-color-system-text-colors-tertiary-text font-button mq450:pb-5 mq450:box-border">
            <div className="flex flex-col items-start justify-start gap-[30px] mq450:gap-[18px]">
              <div className="self-stretch relative leading-[normal] inline-block w-[300px] h-0 shrink-0 [transform:_rotate(90deg)] text-left [transform-origin:0_0] mq450:h-[15px]">
                Employee Actions
              </div>
              <div
                className="relative tracking-[0.03em] leading-[normal] font-semibold text-29xl inline-block w-[150px] h-[60px] shrink-0 text-center z-[0] mq675:w-[170px]"
                onClick={onButtonLabelsContainerClick}
              >
                <span className="inline-block w-[170px] h-10 shrink-0 text-29xl font-semibold text-center text-brooks-color-system-text-colors-secondary-text leading-[normal] uppercase tracking-[0.03em]">
                  Delete Account
                </span>
              </div>
            </div>
          </footer>
        </section>
      </main>
    </div>
  );
};

export default EmployeeProfile;
