import React from 'react';
import { useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar'; 
import '../../styles/ProductList.css';

const CategoryList = () => {
  const navigate = useNavigate();

  // Updated categories array with names and specifications
  const categories = [
    { name: 'Shirts', image: 'https://brooksbingham.com/51-large_default/light-blue-jetstream.jpg', description: 'shirts' },
    { name: 'Suits', image: 'https://img.freepik.com/free-psd/realistic-suit-illustration_23-2151236757.jpg?t=st=1722512180~exp=1722515780~hmac=79030884ba3866ce8461b252477505e74e625c63012705c110eced45b59c63fb&w=740', description: 'suits' },
    { name: 'Tuxedos', image: 'https://img.freepik.com/premium-vector/businessman-suit_98292-5674.jpg?w=740', description: 'tuxedos' },
    { name: 'Jackets', image: 'https://i5.walmartimages.com/seo/Lmtime-Clearance-Men-s-Casual-Blazer-Suit-Jackets-Slim-Fit-Lightweight-Sport-Coat-Business-Coat-Suit-Tops-Jacket-One-Button-Grey-XXL_4277f765-9e49-4ed1-a4b1-c70c71d3d1f0.5c005fe2c8e9d110bfb00216fb52f77b.jpeg?odnHeight=768&odnWidth=768&odnBg=FFFFFF', description: 'jackets' },
  ];

  const handleClick = (category) => {
    navigate(`/products/${category}`);
  };

  return (
    <div className="flex h-screen">
      {/* Sidebar */}
      <Sidebar />

      {/* Main content */}
      <div className="flex-grow flex flex-col">
        <div className="bg-white p-4 flex items-center">
          <h1 className="ml-4 text-2xl font-medium text-gray-700">Categories</h1>
        </div>
        <div className="flex-grow p-8">
          <div className="grid grid-cols-2 gap-8">
            {categories.map((category, index) => (
              <div
                key={index}
                className="border border-gray-300 p-4 rounded-lg cursor-pointer hover:shadow-lg transition-shadow duration-300 ease-in-out flex flex-col items-center"
                onClick={() => handleClick(category.name.toLowerCase())} // Updated to handle lowercase category names
              >
                <img src={category.image} alt={category.name} className="w-48 h-48 object-cover" />
                <h2 className="text-xl font-bold text-center mt-2 capitalize">{category.name}</h2>
                <p className="ml-4 text-2xl font-medium text-gray-700">{category.description}</p>
                <p className="text-center text-sm text-gray-600 mt-1">Click to view products</p>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};
export default CategoryList;
