import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';
import '../../styles/CustomerList.css';
import {getAllCustomers} from '../../services_1/customersService'



const CustomerList = () => {
  const [customers, setCustomers] = useState([]);
  const navigate = useNavigate();

  useEffect(() => {
    getCustomers();
  }, []);

  const getCustomers = async () => {
    try {
      const data = await getAllCustomers()
      setCustomers(data);
    } catch (error) {
      throw error;
    }
  };

  const handleAddCustomer = () => {
    navigate('/add-customer');
  };

  return (
    <div className="flex flex-row min-h-screen">
      <Sidebar />
      <div className="flex-grow p-6 bg-gray-100">
        <div className="bg-white p-6 rounded-lg shadow">
          <div className="flex justify-between items-center ">
            <h1 className="text-2xl font-semibold text-gray-800">customers list</h1>
            <button
              className="bg-#0e355b text-#d1d5db px-4 py-2 rounded-md text-sm"
              onClick={handleAddCustomer}
            >
              add new customer
            </button>
          </div>
          <div className="flex items-center ">
            <svg
              className="w-5 h-5  text-gray-500"
              fill="none"
              stroke="currentColor"
              viewBox="0 0 24 24"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                strokeLinecap="round"
                strokeLinejoin="round"
                strokeWidth={2}
                d="M3 4a1 1 0 011-1h16a1 1 0 011 1v2.586a1 1 0 01-.293.707l-6.414 6.414a1 1 0 00-.293.707V17l-4 4v-6.586a1 1 0 00-.293-.707L3.293 7.293A1 1 0 013 6.586V4z"
              />
            </svg>
            <span className="text-sm text-gray-600">filter</span>
          </div>
          <p className="text-sm text-gray-600 ">total customers ({customers.length})</p>
          <table className="w-full bg-white">
            <thead>
              <tr className="text-left text-xs uppercase text-gray-600 border-b">
                <th className="py-2">#</th>
                <th className="py-2">customer id</th>
                <th className="py-2">customer fullname</th>
              </tr>
            </thead>
            <tbody>
              {customers.map((customer, index) => (
                <tr key={customer.id} className="border-b last:border-none">
                  <td className="py-2 text-gray-800">{index + 1}</td>
                  <td className="py-2 text-gray-800">{customer.id}</td>
                  <td className="py-2 text-gray-800">{customer.firstname} {customer.lastname} </td>
                  
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  );
};

export default CustomerList;
