import React from 'react';
import { Button, Input, Form } from 'antd';
import { Link } from 'react-router-dom';
import axios from 'axios';
import Sidebar from '../sidebar/Sidebar';
import '../../styles/CustomerMeasurements.css';

const CustomerMeasurements = () => {
  const onFinish = async (values) => {
    const token = localStorage.getItem('token'); // Assuming the token is stored in localStorage

    try {
      const response = await axios.post('http://localhost:5000/measurements', values, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      });

      console.log(response.data);
    } catch (error) {
      console.error('Error saving measurements:', error);
    }
  };

  return (
    <div className="container flex">
      <Sidebar />
      <div className="content flex-1">
        <div className="form-container max-w-2xl mx-auto p-6">
          <div className="header flex justify-between items-left mb-4">
            <h1 className="mml-4 text-2xl font-semibold text-gray-700">customer measurements</h1>
            <Link to="/CategoryList" className="skip-link ">skip for now</Link>
          </div>
          <Form onFinish={onFinish} className="form space-y-4">
            <h2 className="section-title text-lg font-medium">Upper Body Measurements</h2>
            <Form.Item name="neck" label="Neck Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="chest" label="Chest Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="waist" label="Waist Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="shoulder" label="Shoulder Width (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="arm" label="Arm Length (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="sleeve" label="Sleeve Length (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>

            <h2 className="section-title text-lg font-medium">Lower Body Measurements</h2>
            <Form.Item name="hip" label="Hip Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="inseam" label="Inseam (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="outseam" label="Outseam (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="thigh" label="Thigh Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item name="ankle" label="Ankle Circumference (in inch)">
              <Input className="input focus:outline-none focus:ring-0 border-b border-gray-400" />
            </Form.Item>
            <Form.Item>
              <div className="button-container flex justify-end">
                <Button type="primary" htmlType="submit" className="submit-button bg-[#0e355b] text-white py-2 px-4 rounded-md">
                  Save Measurements
                </Button>
              </div>
            </Form.Item>
          </Form>
        </div>
      </div>
    </div>
  );
};

export default CustomerMeasurements;
