import React from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar'; 
import '../../styles/Measurements.css';

const CustomMeasurements = () => {
  const navigate = useNavigate();

  const handleCheckout = () => {
    navigate('/checkout');
  };

  return (
    <div className="flex">
      <Sidebar />
      <div className="w-full ml-10 p-2">
        <div className="bg-white p-4 flex items-center">
          <Link to="/setmeasurements"> 
            <FontAwesomeIcon icon={faChevronLeft} />
          </Link>
          <h1 className="ml-4 text-2xl font-medium text-gray-700">custom measurements</h1>
        </div>
        
        <div className="mt-4 flex-">
          <img
            src="https://5.imimg.com/data5/HM/AE/VV/SELLER-77211399/white-plain-tshirts.jpg"
            alt="Product"
            className="w-1/3 h-auto mr-4"
          />

          <div className="w-2/3">
            <p className="text-xl mb-2 text-gray-700">product name: blue aces</p>
            <p className="text-xl mb-4 text-gray-700">$99.00</p>
            <form className="bg-white p-6 rounded shadow">
              <h2 className="text-lg mb-4 text-gray-700 font-semibold">upper body measurements</h2>
              <div className="flex flex-wrap mb-4">
                <div className="w-1/2 mb-2">
                  <label htmlFor="neck-circumference" className="block text-sm font-medium text-gray-700">
                    neck circumference (in inch):
                  </label>
                  <input
                    id="neck-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter neck size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="chest-circumference" className="block text-sm font-medium text-gray-700">
                    chest circumference (in inch):
                  </label>
                  <input
                    id="chest-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter chest size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="waist-circumference" className="block text-sm font-medium text-gray-700">
                    waist circumference (in inch):
                  </label>
                  <input
                    id="waist-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter waist size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="shoulder-width" className="block text-sm font-medium text-gray-700">
                    shoulder width (in inch):
                  </label>
                  <input
                    id="shoulder-width"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter shoulder size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="arm-length" className="block text-sm font-medium text-gray-700">
                    arm length (in inch):
                  </label>
                  <input
                    id="arm-length"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter arm size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="sleeve-length" className="block text-sm font-medium text-gray-700">
                    sleeve length (in inch):
                  </label>
                  <input
                    id="sleeve-length"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter sleeve size"
                  />
                </div>
              </div>

              <h2 className="text-lg mb-4 text-gray-700 font-semibold">lower body measurements</h2>
              <div className="flex flex-wrap mb-4">
                <div className="w-1/2 mb-2">
                  <label htmlFor="hip-circumference" className="block text-sm font-medium text-gray-700">
                    hip circumference (in inch):
                  </label>
                  <input
                    id="hip-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter hip size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="inseam" className="block text-sm font-medium text-gray-700">
                    inseam (in inch):
                  </label>
                  <input
                    id="inseam"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter inseam size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="outseam" className="block text-sm font-medium text-gray-700">
                    outseam (in inch):
                  </label>
                  <input
                    id="outseam"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter outseam size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="thigh-circumference" className="block text-sm font-medium text-gray-700">
                    thigh circumference (in inch):
                  </label>
                  <input
                    id="thigh-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter thigh size"
                  />
                </div>
                <div className="w-1/2 mb-2">
                  <label htmlFor="ankle-circumference" className="block text-sm font-medium text-gray-700">
                    ankle circumference (in inch):
                  </label>
                  <input
                    id="ankle-circumference"
                    type="text"
                    className="mt-1 block border border-gray-300 rounded py-2 px-3"
                    placeholder="Enter ankle size"
                  />
                </div>
              </div>
              <button
                type="submit"
                className="py-2 px-4 mb-4 "
              >
                save measurements
              </button>
              <span className="text-gray-700 cursor-pointer hover:underline ml-2">
                edit measurements
              </span>
            </form>
            <button
              onClick={handleCheckout}
              className="mt-6 py-2 px-4 "
            >
              continue to checkout
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default CustomMeasurements;
