import React, { useState } from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar';

const SetMeasurements = () => {
  const [selectedOption, setSelectedOption] = useState('standard');
  const navigate = useNavigate();

  const handleOptionChange = (event) => {
    setSelectedOption(event.target.value);
  };

  const handleContinue = () => {
    if (selectedOption === 'standard') {
      navigate('/measurements/standard');
    } else {
      navigate('/measurements/custom');
    }
  };

  return (
    <div className="flex h-screen">
      <Sidebar />
      <div className="flex-grow flex flex-col">
        <div className="bg-white p-4 flex items-center">
          <Link to="/customize/:id">
            <FontAwesomeIcon icon={faChevronLeft} />
          </Link>
          <h1 className="ml-4 text-2xl font-medium text-gray-700">set measurements</h1>
        </div>
        <div className="flex-grow flex items-start justify-end p-8">
          <div className="bg-white p-6 rounded-lg  w-full max-w-md">
            <div className="mb-4">
              <label className="block text-sm font-medium text-gray-700">
                <input
                  type="radio"
                  value="standard"
                  checked={selectedOption === 'standard'}
                  onChange={handleOptionChange}
                  className="mr-2"
                />
                standard measurements
              </label>
              <label className="block text-sm font-medium text-gray-700 mt-2">
                <input
                  type="radio"
                  value="custom"
                  checked={selectedOption === 'custom'}
                  onChange={handleOptionChange}
                  className="mr-2"
                />
                custom measurements
              </label>
            </div>
            <button
              onClick={handleContinue}
              className=" py-2 px-4 "
            >
              continue
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default SetMeasurements;
