import React, { useState, useEffect } from 'react';
import ordersService from './ordersService';

const Orders = () => {
  const [orders, setOrders] = useState([]);
  const [order, setOrder] = useState(null);
  const [error, setError] = useState(null);

  useEffect(() => {
    fetchOrders();
  }, []);

  const fetchOrders = async () => {
    try {
      const data = await ordersService.getAllOrders();
      setOrders(data);
    } catch (error) {
      setError('Error fetching orders');
    }
  };

  const fetchOrderById = async (id) => {
    try {
      const data = await ordersService.getOrderById(id);
      setOrder(data);
    } catch (error) {
      setError('Error fetching order');
    }
  };

  const addOrder = async (orderData) => {
    try {
      const data = await ordersService.createOrder(orderData);
      setOrders([...orders, data]);
    } catch (error) {
      setError('Error adding order');
    }
  };

  const updateOrder = async (id, updatedData) => {
    try {
      const data = await ordersService.updateOrder(id, updatedData);
      setOrders(orders.map(o => (o.id === id ? data : o)));
    } catch (error) {
      setError('Error updating order');
    }
  };

  const deleteOrder = async (id) => {
    try {
      await ordersService.deleteOrder(id);
      setOrders(orders.filter(o => o.id !== id));
    } catch (error) {
      setError('Error deleting order');
    }
  };

  return (
    <div>
      <h1>Orders</h1>
      {error && <p>{error}</p>}
      {/* Render orders list here */}
      {/* Example of calling fetchOrderById */}
      {/* <button onClick={() => fetchOrderById('order-id')}>Fetch Order</button> */}
      {/* Example of calling addOrder */}
      {/* <button onClick={() => addOrder({ subtotal: 100, tax_rate: 0.1, tax_amount: 10, total: 110, status: 'pending' })}>Add Order</button> */}
      {/* Example of calling updateOrder */}
      {/* <button onClick={() => updateOrder('order-id', { status: 'shipped' })}>Update Order</button> */}
      {/* Example of calling deleteOrder */}
      {/* <button onClick={() => deleteOrder('order-id')}>Delete Order</button> */}
    </div>
  );
};

export default Orders;
