import axiosInstance from "../api/axiosConfig"; // Import the global axios instance

// Get all categories
export const getAllCategories = async () => {
  try {
    const response = await axiosInstance.get("/categories");
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Create a new category
export const createCategory = async (categoryPayload) => {
  try {
    const response = await axiosInstance.post("/categories", categoryPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get a category by ID
export const getCategoryById = async (id) => {
  try {
    const response = await axiosInstance.get(`/categories/${id}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Update a category's details
export const updateCategory = async (id, categoryPayload) => {
  try {
    const response = await axiosInstance.patch(
      `/categories/${id}`,
      categoryPayload
    );
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Delete a category
export const deleteCategory = async (id) => {
  try {
    await axiosInstance.delete(`/categories/${id}`);
    return; // No content to return on successful delete
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Example function to use the service
export const exampleUsage = async () => {
  try {
    // Example: Get all categories
    const categories = await getAllCategories();
    console.log("Categories:", categories);

    // Example: Create a new category
    const newCategory = {
      name: "Electronics",
      description: "Devices and gadgets",
    };
    const createdCategory = await createCategory(newCategory);
    console.log("Created Category:", createdCategory);

    // Example: Get a category by ID
    const categoryId = "456";
    const category = await getCategoryById(categoryId);
    console.log("Category by ID:", category);

    // Example: Update a category
    const updatedCategoryPayload = { name: "Electronics & Gadgets" };
    const updatedCategory = await updateCategory(
      categoryId,
      updatedCategoryPayload
    );
    console.log("Updated Category:", updatedCategory);

    // Example: Delete a category
    await deleteCategory(categoryId);
    console.log("Category deleted successfully");
  } catch (error) {
    console.error("Error occurred while using categories service:", error);
  }
};
