import axiosInstance from "../api/axiosConfig"; // Import the global axios instance

// Get all products with their metadata
export const getAllProducts = async () => {
  try {
    const response = await axiosInstance.get("/products");
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Create a new product
export const createProduct = async (productPayload) => {
  try {
    const response = await axiosInstance.post("/products", productPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get a product by ID
export const getProductById = async (id) => {
  try {
    const response = await axiosInstance.get(`/products/${id}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Update a product's details
export const updateProduct = async (id, productPayload) => {
  try {
    const response = await axiosInstance.patch(
      `/products/${id}`,
      productPayload
    );
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Delete a product
export const deleteProduct = async (id) => {
  try {
    await axiosInstance.delete(`/products/${id}`);
    return; // No content to return on successful delete
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get a product by SKU
export const getProductBySKU = async (sku) => {
  try {
    const response = await axiosInstance.get(`/products/${sku}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Example function to use the service
export const exampleUsage = async () => {
  try {
    // Example: Get all products
    const products = await getAllProducts();
    console.log("Products:", products);

    // Example: Create a new product
    const newProduct = { name: "Laptop", sku: "LPT123", price: 1200 };
    const createdProduct = await createProduct(newProduct);
    console.log("Created Product:", createdProduct);

    // Example: Get a product by ID
    const productId = "789";
    const product = await getProductById(productId);
    console.log("Product by ID:", product);

    // Example: Update a product
    const updatedProductPayload = { price: 1100 };
    const updatedProduct = await updateProduct(
      productId,
      updatedProductPayload
    );
    console.log("Updated Product:", updatedProduct);

    // Example: Delete a product
    await deleteProduct(productId);
    console.log("Product deleted successfully");

    // Example: Get a product by SKU
    const productSKU = "LPT123";
    const productBySKU = await getProductBySKU(productSKU);
    console.log("Product by SKU:", productBySKU);
  } catch (error) {
    console.error("Error occurred while using products service:", error);
  }
};
